#
# spec file for package python-ZConfig
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ZConfig
Version:        3.5.0
Release:        bp153.1.19
Summary:        Structured Configuration Library
License:        ZPL-2.1
Group:          Development/Libraries/Python
URL:            https://github.com/zopefoundation/ZConfig
Source:         https://files.pythonhosted.org/packages/source/Z/ZConfig/ZConfig-%{version}.tar.gz
# UPSTREAM PATCH (partial): gh#zopefoundation/ZConfig#70
Patch0:         python-38-support.patch
# Testing requirements:
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module manuel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.testrunner}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
ZConfig is a configuration library intended for general use. It supports a
hierarchical schema-driven configuration model that allows a schema to specify
data conversion routines written in Python. ZConfig's model is very different
from the model supported by the ConfigParser module found in Python's standard
library, and is more suitable to configuration-intensive applications.

ZConfig schema are written in an XML-based language and are able to "import"
schema components provided by Python packages. Since components are able to
bind to conversion functions provided by Python code in the package (or
elsewhere), configuration objects can be arbitrarily complex, with values that
have been verified against arbitrary constraints. This makes it easy for
applications to separate configuration support from configuration loading even
with configuration data being defined and consumed by a wide range of separate
packages.

%package        doc
Summary:        Structured Configuration Library
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description    doc
This package contains documentation files for %{name}.

%prep
%setup -q -n ZConfig-%{version}
%autopatch -p1
rm -rf ZConfig.egg-info
rm doc/make.bat
# test works only in git repo
rm -f ZConfig/tests/test_readme.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/zconfig
%python_clone -a %{buildroot}%{_bindir}/zconfig_schema2html

%check
export LANG=en_US.UTF8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} zope-testrunner-%{$python_bin_suffix} -v --test-path=.

%post
%python_install_alternative zconfig zconfig_schema2html

%preun
%python_uninstall_alternative zconfig

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt PKG-INFO README.rst
%python_alternative %{_bindir}/zconfig
%python_alternative %{_bindir}/zconfig_schema2html
%{python_sitelib}/*

%files %{python_files doc}
%doc doc/

%changelog
* Mon Nov 25 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add python-38-support.patch to support Python 3.8
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 3.5.0
  * Add support for documenting schema files contained in packages to
    the Sphinx extension. See `issue 59
    <https://github.com/zopefoundation/ZConfig/issues/59>`_.
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.0:
  * Many changes have been made in the support for logging configurations
  * Drop support for Python 3.3.
  * Add support for Python 3.7.
  * Drop support for 'python setup.py test'. See issue 38.
  * Add support for example in section and multisection, and include those examples in generated documentation. See https://github.com/zopefoundation/ZConfig/pull/5.
  * Fix configuration loaders to decode byte data using UTF-8 instead of the default encoding (usually ASCII). See issue 37.
* Fri Jun 23 2017 aloisio@gmx.com
- Update to 3.2.0
  * Drop support for Python 2.6 and 3.2 and add support for
    Python 3.6.
  * Run tests with pypy and pypy3 as well.
  * Host docs at https://zconfig.readthedocs.io
  * BaseLoader is now an abstract class that cannot be
    instantiated.
  * Allow nan, inf and -inf values for floats in configurations.
    See https://github.com/zopefoundation/ZConfig/issues/16.
  * Scripts zconfig (for schema validation) and
    zconfig_schema2html are ported to Python 3.
  * A new ZConfig.sphinx Sphinx extension facilitates
    automatically documenting ZConfig components using their
    description and examples in Sphinx documentation. See
    https://github.com/zopefoundation/ZConfig/pull/25.
  * Simplify internal schema processing of max and min
    occurrence values. See
    https://github.com/zopefoundation/ZConfig/issues/15.
  * Almost all uses of type as a parameter name have been
    replaced with type_ to avoid shadowing a builtin. These were
    typically not public APIs and weren’t expected to be called
    with  keyword arguments so there should not be any
    user-visible  changes.
    See https://github.com/zopefoundation/ZConfig/issues/17
  3.1.0:
  * Add ability to do variable substitution from environment
    variables using $() syntax.
- Converted to single-spec
* Wed Apr 16 2014 p.drouand@gmail.com
- Update to version 3.0.4
  + Added Python 3.4 support
- Implement update-alternatives
* Thu Sep 26 2013 toddrme2178@gmail.com
- Fix source URL
* Sat Aug  3 2013 hpj@urpla.net
- version 3.0.3: initial build
